# coding: utf-8

"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.8.161005
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from vrt_ud.configuration import Configuration


class FactPerformerMessage(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'performer_id': 'str',
        'trip_id': 'str',
        'transport_id': 'str',
        'message_topic': 'str',
        'message': 'str',
        'storage_server_file_ids': 'list[str]',
        'fact_time': 'datetime'
    }

    attribute_map = {
        'performer_id': 'performer_id',
        'trip_id': 'trip_id',
        'transport_id': 'transport_id',
        'message_topic': 'message_topic',
        'message': 'message',
        'storage_server_file_ids': 'storage_server_file_ids',
        'fact_time': 'fact_time'
    }

    def __init__(self, performer_id=None, trip_id=None, transport_id=None, message_topic=None, message=None, storage_server_file_ids=None, fact_time=None, local_vars_configuration=None):  # noqa: E501
        """FactPerformerMessage - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._performer_id = None
        self._trip_id = None
        self._transport_id = None
        self._message_topic = None
        self._message = None
        self._storage_server_file_ids = None
        self._fact_time = None
        self.discriminator = None

        self.performer_id = performer_id
        self.trip_id = trip_id
        self.transport_id = transport_id
        self.message_topic = message_topic
        if message is not None:
            self.message = message
        self.storage_server_file_ids = storage_server_file_ids
        if fact_time is not None:
            self.fact_time = fact_time

    @property
    def performer_id(self):
        """Gets the performer_id of this FactPerformerMessage.  # noqa: E501

        Performer's ID.  # noqa: E501

        :return: The performer_id of this FactPerformerMessage.  # noqa: E501
        :rtype: str
        """
        return self._performer_id

    @performer_id.setter
    def performer_id(self, performer_id):
        """Sets the performer_id of this FactPerformerMessage.

        Performer's ID.  # noqa: E501

        :param performer_id: The performer_id of this FactPerformerMessage.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and performer_id is None:  # noqa: E501
            raise ValueError("Invalid value for `performer_id`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                performer_id is not None and len(performer_id) > 1024):
            raise ValueError("Invalid value for `performer_id`, length must be less than or equal to `1024`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                performer_id is not None and len(performer_id) < 1):
            raise ValueError("Invalid value for `performer_id`, length must be greater than or equal to `1`")  # noqa: E501

        self._performer_id = performer_id

    @property
    def trip_id(self):
        """Gets the trip_id of this FactPerformerMessage.  # noqa: E501

        Trip ID.  # noqa: E501

        :return: The trip_id of this FactPerformerMessage.  # noqa: E501
        :rtype: str
        """
        return self._trip_id

    @trip_id.setter
    def trip_id(self, trip_id):
        """Sets the trip_id of this FactPerformerMessage.

        Trip ID.  # noqa: E501

        :param trip_id: The trip_id of this FactPerformerMessage.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and trip_id is None:  # noqa: E501
            raise ValueError("Invalid value for `trip_id`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                trip_id is not None and len(trip_id) > 1024):
            raise ValueError("Invalid value for `trip_id`, length must be less than or equal to `1024`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                trip_id is not None and len(trip_id) < 1):
            raise ValueError("Invalid value for `trip_id`, length must be greater than or equal to `1`")  # noqa: E501

        self._trip_id = trip_id

    @property
    def transport_id(self):
        """Gets the transport_id of this FactPerformerMessage.  # noqa: E501

        Vehicle ID.  # noqa: E501

        :return: The transport_id of this FactPerformerMessage.  # noqa: E501
        :rtype: str
        """
        return self._transport_id

    @transport_id.setter
    def transport_id(self, transport_id):
        """Sets the transport_id of this FactPerformerMessage.

        Vehicle ID.  # noqa: E501

        :param transport_id: The transport_id of this FactPerformerMessage.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and transport_id is None:  # noqa: E501
            raise ValueError("Invalid value for `transport_id`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                transport_id is not None and len(transport_id) > 1024):
            raise ValueError("Invalid value for `transport_id`, length must be less than or equal to `1024`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                transport_id is not None and len(transport_id) < 1):
            raise ValueError("Invalid value for `transport_id`, length must be greater than or equal to `1`")  # noqa: E501

        self._transport_id = transport_id

    @property
    def message_topic(self):
        """Gets the message_topic of this FactPerformerMessage.  # noqa: E501

        Message topic.  # noqa: E501

        :return: The message_topic of this FactPerformerMessage.  # noqa: E501
        :rtype: str
        """
        return self._message_topic

    @message_topic.setter
    def message_topic(self, message_topic):
        """Sets the message_topic of this FactPerformerMessage.

        Message topic.  # noqa: E501

        :param message_topic: The message_topic of this FactPerformerMessage.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and message_topic is None:  # noqa: E501
            raise ValueError("Invalid value for `message_topic`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                message_topic is not None and len(message_topic) > 1000):
            raise ValueError("Invalid value for `message_topic`, length must be less than or equal to `1000`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                message_topic is not None and len(message_topic) < 1):
            raise ValueError("Invalid value for `message_topic`, length must be greater than or equal to `1`")  # noqa: E501

        self._message_topic = message_topic

    @property
    def message(self):
        """Gets the message of this FactPerformerMessage.  # noqa: E501

        Message text.  # noqa: E501

        :return: The message of this FactPerformerMessage.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this FactPerformerMessage.

        Message text.  # noqa: E501

        :param message: The message of this FactPerformerMessage.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                message is not None and len(message) > 10000):
            raise ValueError("Invalid value for `message`, length must be less than or equal to `10000`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                message is not None and len(message) < 1):
            raise ValueError("Invalid value for `message`, length must be greater than or equal to `1`")  # noqa: E501

        self._message = message

    @property
    def storage_server_file_ids(self):
        """Gets the storage_server_file_ids of this FactPerformerMessage.  # noqa: E501

        Attached files IDs.  # noqa: E501

        :return: The storage_server_file_ids of this FactPerformerMessage.  # noqa: E501
        :rtype: list[str]
        """
        return self._storage_server_file_ids

    @storage_server_file_ids.setter
    def storage_server_file_ids(self, storage_server_file_ids):
        """Sets the storage_server_file_ids of this FactPerformerMessage.

        Attached files IDs.  # noqa: E501

        :param storage_server_file_ids: The storage_server_file_ids of this FactPerformerMessage.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and storage_server_file_ids is None:  # noqa: E501
            raise ValueError("Invalid value for `storage_server_file_ids`, must not be `None`")  # noqa: E501

        self._storage_server_file_ids = storage_server_file_ids

    @property
    def fact_time(self):
        """Gets the fact_time of this FactPerformerMessage.  # noqa: E501

        Fact time in the [RFC 3339, section 5.6](https://tools.ietf.org/html/rfc3339#section-5.6) format.  # noqa: E501

        :return: The fact_time of this FactPerformerMessage.  # noqa: E501
        :rtype: datetime
        """
        return self._fact_time

    @fact_time.setter
    def fact_time(self, fact_time):
        """Sets the fact_time of this FactPerformerMessage.

        Fact time in the [RFC 3339, section 5.6](https://tools.ietf.org/html/rfc3339#section-5.6) format.  # noqa: E501

        :param fact_time: The fact_time of this FactPerformerMessage.  # noqa: E501
        :type: datetime
        """

        self._fact_time = fact_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FactPerformerMessage):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FactPerformerMessage):
            return True

        return self.to_dict() != other.to_dict()
