# coding: utf-8

"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.8.161005
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import vrt_ud
from vrt_ud.models.capacity import Capacity  # noqa: E501
from vrt_ud.rest import ApiException

class TestCapacity(unittest.TestCase):
    """Capacity unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Capacity
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = vrt_ud.models.capacity.Capacity()  # noqa: E501
        if include_optional :
            return Capacity(
                mass = 10, 
                volume = 2, 
                capacity_x = 1, 
                capacity_y = 2, 
                capacity_z = 3
            )
        else :
            return Capacity(
                mass = 10,
        )

    def testCapacity(self):
        """Test Capacity"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
