# coding: utf-8

"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.8.161005
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import vrt_ud
from vrt_ud.models.trip_action import TripAction  # noqa: E501
from vrt_ud.rest import ApiException

class TestTripAction(unittest.TestCase):
    """TripAction unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test TripAction
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = vrt_ud.models.trip_action.TripAction()  # noqa: E501
        if include_optional :
            return TripAction(
                order_key = 'order01', 
                demand_key = 'demand01.1', 
                location_key = 'location01', 
                todolist = [
                    vrt_ud.models.trip_job.TripJob(
                        job_type = 'START_WORK', 
                        job_time = '2020-10-21T09:30+03:00', )
                    ], 
                cargo_placements = [
                    vrt_ud.models.cargo_placement.CargoPlacement(
                        box_key = 'box01', 
                        cargo_key = 'cargo01', )
                    ]
            )
        else :
            return TripAction(
                order_key = 'order01',
                demand_key = 'demand01.1',
                location_key = 'location01',
                todolist = [
                    vrt_ud.models.trip_job.TripJob(
                        job_type = 'START_WORK', 
                        job_time = '2020-10-21T09:30+03:00', )
                    ],
        )

    def testTripAction(self):
        """Test TripAction"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
