# coding: utf-8

"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.8.161005
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from vrt_ud.configuration import Configuration


class PerformerTrack(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'shift_key': 'str',
        'points': 'list[TrackPoint]',
        'last_point': 'TrackPoint'
    }

    attribute_map = {
        'shift_key': 'shift_key',
        'points': 'points',
        'last_point': 'last_point'
    }

    def __init__(self, shift_key=None, points=None, last_point=None, local_vars_configuration=None):  # noqa: E501
        """PerformerTrack - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._shift_key = None
        self._points = None
        self._last_point = None
        self.discriminator = None

        self.shift_key = shift_key
        if points is not None:
            self.points = points
        self.last_point = last_point

    @property
    def shift_key(self):
        """Gets the shift_key of this PerformerTrack.  # noqa: E501

        Shift key.  # noqa: E501

        :return: The shift_key of this PerformerTrack.  # noqa: E501
        :rtype: str
        """
        return self._shift_key

    @shift_key.setter
    def shift_key(self, shift_key):
        """Sets the shift_key of this PerformerTrack.

        Shift key.  # noqa: E501

        :param shift_key: The shift_key of this PerformerTrack.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and shift_key is None:  # noqa: E501
            raise ValueError("Invalid value for `shift_key`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                shift_key is not None and len(shift_key) > 256):
            raise ValueError("Invalid value for `shift_key`, length must be less than or equal to `256`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                shift_key is not None and len(shift_key) < 1):
            raise ValueError("Invalid value for `shift_key`, length must be greater than or equal to `1`")  # noqa: E501

        self._shift_key = shift_key

    @property
    def points(self):
        """Gets the points of this PerformerTrack.  # noqa: E501

        Track points list.  # noqa: E501

        :return: The points of this PerformerTrack.  # noqa: E501
        :rtype: list[TrackPoint]
        """
        return self._points

    @points.setter
    def points(self, points):
        """Sets the points of this PerformerTrack.

        Track points list.  # noqa: E501

        :param points: The points of this PerformerTrack.  # noqa: E501
        :type: list[TrackPoint]
        """

        self._points = points

    @property
    def last_point(self):
        """Gets the last_point of this PerformerTrack.  # noqa: E501


        :return: The last_point of this PerformerTrack.  # noqa: E501
        :rtype: TrackPoint
        """
        return self._last_point

    @last_point.setter
    def last_point(self, last_point):
        """Sets the last_point of this PerformerTrack.


        :param last_point: The last_point of this PerformerTrack.  # noqa: E501
        :type: TrackPoint
        """

        self._last_point = last_point

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PerformerTrack):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PerformerTrack):
            return True

        return self.to_dict() != other.to_dict()
