# coding: utf-8

"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.8.161005
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import vrt_ud
from vrt_ud.api.configurator_api import ConfiguratorApi  # noqa: E501
from vrt_ud.rest import ApiException


class TestConfiguratorApi(unittest.TestCase):
    """ConfiguratorApi unit test stubs"""

    def setUp(self):
        self.api = vrt_ud.api.configurator_api.ConfiguratorApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_cfg(self):
        """Test case for create_cfg

        Configuration change.  # noqa: E501
        """
        pass

    def test_delete_cfg(self):
        """Test case for delete_cfg

        Configuration removal.  # noqa: E501
        """
        pass

    def test_read_cfg(self):
        """Test case for read_cfg

        Reading the configuration.  # noqa: E501
        """
        pass

    def test_read_cfg_names(self):
        """Test case for read_cfg_names

        Reading the configuration names.  # noqa: E501
        """
        pass

    def test_update_cfg(self):
        """Test case for update_cfg

        Configuration parameter change.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
