# coding: utf-8

"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.8.161005
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import vrt_ud
from vrt_ud.api.reports_api import ReportsApi  # noqa: E501
from vrt_ud.rest import ApiException


class TestReportsApi(unittest.TestCase):
    """ReportsApi unit test stubs"""

    def setUp(self):
        self.api = vrt_ud.api.reports_api.ReportsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_generate_report(self):
        """Test case for generate_report

        Generating the report by filter.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
