# coding: utf-8

"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.8.161005
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from vrt_ud.configuration import Configuration


class DataLoadMultipartTask(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'file': 'file',
        'time_shift_hours': 'int',
        'save': 'bool'
    }

    attribute_map = {
        'file': 'file',
        'time_shift_hours': 'time_shift_hours',
        'save': 'save'
    }

    def __init__(self, file=None, time_shift_hours=0, save=True, local_vars_configuration=None):  # noqa: E501
        """DataLoadMultipartTask - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._file = None
        self._time_shift_hours = None
        self._save = None
        self.discriminator = None

        self.file = file
        if time_shift_hours is not None:
            self.time_shift_hours = time_shift_hours
        if save is not None:
            self.save = save

    @property
    def file(self):
        """Gets the file of this DataLoadMultipartTask.  # noqa: E501

        File contents.  # noqa: E501

        :return: The file of this DataLoadMultipartTask.  # noqa: E501
        :rtype: file
        """
        return self._file

    @file.setter
    def file(self, file):
        """Sets the file of this DataLoadMultipartTask.

        File contents.  # noqa: E501

        :param file: The file of this DataLoadMultipartTask.  # noqa: E501
        :type: file
        """
        if self.local_vars_configuration.client_side_validation and file is None:  # noqa: E501
            raise ValueError("Invalid value for `file`, must not be `None`")  # noqa: E501

        self._file = file

    @property
    def time_shift_hours(self):
        """Gets the time_shift_hours of this DataLoadMultipartTask.  # noqa: E501

        The times in the data will be shifted during loading for the specified time period in hours, and both positive and negative values are accepted.  # noqa: E501

        :return: The time_shift_hours of this DataLoadMultipartTask.  # noqa: E501
        :rtype: int
        """
        return self._time_shift_hours

    @time_shift_hours.setter
    def time_shift_hours(self, time_shift_hours):
        """Sets the time_shift_hours of this DataLoadMultipartTask.

        The times in the data will be shifted during loading for the specified time period in hours, and both positive and negative values are accepted.  # noqa: E501

        :param time_shift_hours: The time_shift_hours of this DataLoadMultipartTask.  # noqa: E501
        :type: int
        """

        self._time_shift_hours = time_shift_hours

    @property
    def save(self):
        """Gets the save of this DataLoadMultipartTask.  # noqa: E501

        Save the file after uploading to the server.  # noqa: E501

        :return: The save of this DataLoadMultipartTask.  # noqa: E501
        :rtype: bool
        """
        return self._save

    @save.setter
    def save(self, save):
        """Sets the save of this DataLoadMultipartTask.

        Save the file after uploading to the server.  # noqa: E501

        :param save: The save of this DataLoadMultipartTask.  # noqa: E501
        :type: bool
        """

        self._save = save

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DataLoadMultipartTask):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DataLoadMultipartTask):
            return True

        return self.to_dict() != other.to_dict()
