# coding: utf-8

"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.8.161005
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import vrt_ud
from vrt_ud.api.monitor_api import MonitorApi  # noqa: E501
from vrt_ud.rest import ApiException


class TestMonitorApi(unittest.TestCase):
    """MonitorApi unit test stubs"""

    def setUp(self):
        self.api = vrt_ud.api.monitor_api.MonitorApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_read_facts(self):
        """Test case for read_facts

        Getting the facts for a period of time  # noqa: E501
        """
        pass

    def test_read_performers(self):
        """Test case for read_performers

        Getting current information about the performer by filter.  # noqa: E501
        """
        pass

    def test_read_trips(self):
        """Test case for read_trips

        Getting the trips by filter.  # noqa: E501
        """
        pass

    def test_run_trips(self):
        """Test case for run_trips

        Trips launching.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
