# coding: utf-8

"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.8.161005
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import vrt_ud
from vrt_ud.api.data_api import DataApi  # noqa: E501
from vrt_ud.rest import ApiException


class TestDataApi(unittest.TestCase):
    """DataApi unit test stubs"""

    def setUp(self):
        self.api = vrt_ud.api.data_api.DataApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_clean_data(self):
        """Test case for clean_data

        Removing the data for a period of time.  # noqa: E501
        """
        pass

    def test_download_photo(self):
        """Test case for download_photo

        Downloading the photo by ID.  # noqa: E501
        """
        pass

    def test_find_photos(self):
        """Test case for find_photos

        Getting the photo IDs by filter.  # noqa: E501
        """
        pass

    def test_load_data(self):
        """Test case for load_data

        Loading the data from file in the form of base64 line.  # noqa: E501
        """
        pass

    def test_load_data_file(self):
        """Test case for load_data_file

        Data loading from a file.  # noqa: E501
        """
        pass

    def test_read_orders(self):
        """Test case for read_orders

        Getting the order by filter.  # noqa: E501
        """
        pass

    def test_remove_orders(self):
        """Test case for remove_orders

        Removing the orders by filter.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
