# coding: utf-8

"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.8.161005
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "vrt_ud"
VERSION = "2.8.161005"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

setup(
    name=NAME,
    version=VERSION,
    description="VeeRoute.UD",
    author="VeeRoute Support Team",
    author_email="support@veeroute.com",
    url="https://docs.veeroute.com/#/udl/integration/openapi",
    keywords=["OpenAPI", "OpenAPI-Generator", "VeeRoute.UD"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    long_description="""\
    VeeRoute.UD API  # noqa: E501
    """
)
